@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-adblock-extension.c,v 1.12 2006/05/17 20:04:56 jframeau Exp $
+ *  $Id: ephy-adblock-extension.c,v 1.12.2.1 2006/09/06 20:12:01 chpe Exp $
  */
 
 #include "config.h"
@@ -76,7 +76,7 @@ ephy_adblock_extension_get_type (void)
 GType
 ephy_adblock_extension_register_type (GTypeModule *module)
 {
-	static const GTypeInfo our_info =
+	const GTypeInfo our_info =
 	{
 		sizeof (EphyAdblockExtensionClass),
 		NULL, /* base_init */
@@ -89,14 +89,14 @@ ephy_adblock_extension_register_type (GTypeModule *module)
 		(GInstanceInitFunc) ephy_adblock_extension_init
 	};
 
-	static const GInterfaceInfo adblock_info =
+	const GInterfaceInfo adblock_info =
 	{
 		(GInterfaceInitFunc) ephy_adblock_adblock_iface_init,
 		NULL,
 		NULL
 	};
 
-	static const GInterfaceInfo extension_info =
+	const GInterfaceInfo extension_info =
 	{
 		(GInterfaceInitFunc) ephy_adblock_extension_iface_init,
 		NULL,
