@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-auto-scroller-extension.c,v 1.8 2005/12/08 13:36:55 chpe Exp $
+ *  $Id: ephy-auto-scroller-extension.c,v 1.8.4.1 2006/09/06 20:12:02 chpe Exp $
  */
 
 #include "config.h"
@@ -139,7 +139,7 @@ ephy_auto_scroller_extension_get_type (void)
 GType
 ephy_auto_scroller_extension_register_type (GTypeModule *module)
 {
-	static const GTypeInfo our_info =
+	const GTypeInfo our_info =
 	{
 		sizeof (EphyAutoScrollerExtensionClass),
 		NULL, /* base_init */
@@ -152,7 +152,7 @@ ephy_auto_scroller_extension_register_type (GTypeModule *module)
 		(GInstanceInitFunc) ephy_auto_scroller_extension_init
 	};
 
-	static const GInterfaceInfo extension_info =
+	const GInterfaceInfo extension_info =
 	{
 		(GInterfaceInitFunc) ephy_auto_scroller_extension_iface_init,
 		NULL,
