@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-auto-scroller.c,v 1.11 2006/04/10 20:29:58 chpe Exp $
+ *  $Id: ephy-auto-scroller.c,v 1.11.2.1 2006/09/06 20:12:02 chpe Exp $
  */
 
 /* this file is based on work of Daniel Erat for galeon 1 */
@@ -524,7 +524,7 @@ ephy_auto_scroller_get_type (void)
 GType
 ephy_auto_scroller_register_type (GTypeModule *module)
 {
-	static const GTypeInfo our_info =
+	const GTypeInfo our_info =
 	{
 		sizeof (EphyAutoScrollerClass),
 		NULL, /* base_init */
