@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: error-viewer.c,v 1.16 2005/01/13 16:15:47 chpe Exp $
+ *  $Id: error-viewer.c,v 1.17.4.1 2006/09/06 20:12:10 chpe Exp $
  */
 
 #include "config.h"
@@ -62,12 +62,6 @@ enum
 	N_COLUMNS
 };
 
-/* glade callbacks */
-void error_viewer_clear_cb (GtkWidget *button,
-			    ErrorViewer *dialog);
-void error_viewer_close_cb (GtkWidget *button,
-			    ErrorViewer *dialog);
-
 static void error_viewer_class_init	(ErrorViewerClass *klass);
 static void error_viewer_init		(ErrorViewer *dialog);
 static void error_viewer_finalize	(GObject *object);
@@ -85,7 +79,7 @@ error_viewer_get_type (void)
 GType
 error_viewer_register_type (GTypeModule *module)
 {
-	static const GTypeInfo our_info =
+	const GTypeInfo our_info =
 	{
 		sizeof (ErrorViewerClass),
 		NULL, /* base_init */
@@ -195,6 +189,24 @@ delete_window_cb (GtkWidget *widget,
 	return TRUE;
 }
 
+static void
+response_cb (GtkWidget *widget,
+	     int response,
+	     ErrorViewer *dialog)
+{
+	ErrorViewerPrivate *priv = dialog->priv;
+
+	if (response == 1 /* Clear */)
+	{
+		gtk_list_store_clear (GTK_LIST_STORE (priv->model));
+		gtk_tree_view_columns_autosize (GTK_TREE_VIEW (priv->treeview));
+	
+		return;
+	}
+
+	gtk_widget_hide (widget);
+}
+
 static void
 build_ui (ErrorViewer *dialog)
 {
@@ -213,6 +225,8 @@ build_ui (ErrorViewer *dialog)
 
 	g_signal_connect (priv->window, "delete-event",
 			  G_CALLBACK (delete_window_cb), NULL);
+	g_signal_connect (priv->window, "response",
+			  G_CALLBACK (response_cb), dialog);
 
 	treeview = GTK_TREE_VIEW (priv->treeview);
 
@@ -275,22 +289,6 @@ error_viewer_finalize (GObject *object)
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
-void
-error_viewer_clear_cb (GtkWidget *button,
-		       ErrorViewer *dialog)
-{
-	gtk_list_store_clear (GTK_LIST_STORE (dialog->priv->model));
-
-	gtk_tree_view_columns_autosize (GTK_TREE_VIEW (dialog->priv->treeview));
-}
-
-void
-error_viewer_close_cb (GtkWidget *button,
-		       ErrorViewer *dialog)
-{
-	gtk_widget_hide (dialog->priv->window);
-}
-
 static void
 update_cursor (ErrorViewer *dialog)
 {
