@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: link-checker.c,v 1.10 2005/01/28 22:29:27 chpe Exp $
+ *  $Id: link-checker.c,v 1.10.10.2 2006/09/06 20:24:02 chpe Exp $
  */
 
 #include "config.h"
@@ -34,7 +34,6 @@
 #define MAX_NUM_ROWS 50
 
 static void link_checker_class_init (LinkCheckerClass *klass);
-static void link_checker_class_finalize (LinkCheckerClass *klass);
 static void link_checker_init (LinkChecker *dialog);
 static void link_checker_finalize (GObject *object);
 
@@ -63,13 +62,13 @@ link_checker_get_type (void)
 GType
 link_checker_register_type (GTypeModule *module)
 {
-	static const GTypeInfo our_info =
+	const GTypeInfo our_info =
 	{
 		sizeof (LinkCheckerClass),
 		NULL, /* base_init */
 		NULL, /* base_finalize */
 		(GClassInitFunc) link_checker_class_init,
-		(GClassFinalizeFunc) link_checker_class_finalize,
+		(GClassFinalizeFunc) NULL,
 		NULL, /* class_data */
 		sizeof (LinkChecker),
 		0, /* n_preallocs */
@@ -174,14 +173,6 @@ link_checker_class_init (LinkCheckerClass *klass)
 	object_class->finalize = link_checker_finalize;
 
 	g_type_class_add_private (object_class, sizeof (LinkCheckerPrivate));
-
-	mozilla_register_link_checker_component ();
-}
-
-static void
-link_checker_class_finalize (LinkCheckerClass *klass)
-{
-	mozilla_unregister_link_checker_component ();
 }
 
 static void
