@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: sgml-validator.c,v 1.22 2005/01/28 22:29:27 chpe Exp $
+ *  $Id: sgml-validator.c,v 1.23.4.1 2006/09/06 20:12:10 chpe Exp $
  */
 
 #include "config.h"
@@ -79,7 +79,7 @@ sgml_validator_get_type (void)
 GType
 sgml_validator_register_type (GTypeModule *module)
 {
-	static const GTypeInfo our_info =
+	const GTypeInfo our_info =
 	{
 		sizeof (SgmlValidatorClass),
 		NULL, /* base_init */
@@ -166,7 +166,7 @@ opensp_thread (gpointer data)
 					    "Found %d errors",
 					    osp_data->num_errors),
 				  osp_data->num_errors);
-	complete = g_strdup_printf (_("HTML Validation of %s complete"),
+	complete = g_strdup_printf (_("HTML Validation of “%s” complete"),
 				    osp_data->location);
 
 	summary = g_strconcat (complete, "\n", errors, NULL);
@@ -226,9 +226,9 @@ check_doctype (SgmlValidator *validator,
 			t = g_strdup_printf
 				(_("HTML error in %s:\n%s"),
 				 location,
-				 _("Doctype is \"XHTML\""
-				   " but content type is \"text/html\". "
-				   " Use \"application/xhtml+xml\" instead."));
+				 _("Doctype is “XHTML”"
+				   " but content type is “text/html”. "
+				   " Use “application/xhtml+xml” instead."));
 
 			sgml_validator_append (validator,
 					       ERROR_VIEWER_ERROR, t);
@@ -242,9 +242,9 @@ check_doctype (SgmlValidator *validator,
 			t = g_strdup_printf
 				(_("HTML warning in %s:\n%s"),
 				 location,
-				 _("Doctype is \"XHTML\""
-				   " but content type is \"text/html\". "
-				   " Use \"application/xhtml+xml\" instead."));
+				 _("Doctype is “XHTML”"
+				   " but content type is “text/html”. "
+				   " Use “application/xhtml+xml” instead."));
 
 			sgml_validator_append (validator,
 					       ERROR_VIEWER_WARNING, t);
