@@ -16,12 +16,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: extension.c,v 1.2 2004/12/08 15:33:52 chpe Exp $
+ *  $Id: extension.c,v 1.4 2005/01/28 22:29:41 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-extensions-manager-ui-extension.h"
 #include "extensions-manager-ui.h"
@@ -35,7 +33,7 @@ G_MODULE_EXPORT GType register_module (GTypeModule *module);
 G_MODULE_EXPORT GType
 register_module (GTypeModule *module)
 {
-	LOG ("Registering EphyExtensionsManagerUiExtension")
+	LOG ("Registering EphyExtensionsManagerUiExtension");
 
 #ifdef ENABLE_NLS
        /* Initialise the i18n stuff */
