@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: extensions-manager-ui.c,v 1.21 2006/04/09 20:23:02 chpe Exp $
+ *  $Id: extensions-manager-ui.c,v 1.21.2.1 2006/09/06 20:12:11 chpe Exp $
  */
 
 #include "config.h"
@@ -98,7 +98,7 @@ extensions_manager_ui_get_type (void)
 GType
 extensions_manager_ui_register_type (GTypeModule *module)
 {
-	static const GTypeInfo our_info =
+	const GTypeInfo our_info =
 	{
 		sizeof (ExtensionsManagerUIClass),
 		NULL, /* base_init */
