@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-gestures-extension.c,v 1.24 2005/10/24 16:12:56 philipl Exp $
+ *  $Id: ephy-gestures-extension.c,v 1.24.4.1 2006/09/06 20:12:11 chpe Exp $
  */
 
 #include "config.h"
@@ -68,7 +68,7 @@ ephy_gestures_extension_get_type (void)
 GType
 ephy_gestures_extension_register_type (GTypeModule *module)
 {
-	static const GTypeInfo our_info =
+	const GTypeInfo our_info =
 	{
 		sizeof (EphyGesturesExtensionClass),
 		NULL, /* base_init */
@@ -81,7 +81,7 @@ ephy_gestures_extension_register_type (GTypeModule *module)
 		(GInstanceInitFunc) ephy_gestures_extension_init
 	};
 
-	static const GInterfaceInfo extension_info =
+	const GInterfaceInfo extension_info =
 	{
 		(GInterfaceInitFunc) ephy_gestures_extension_iface_init,
 		NULL,
