@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-greasemonkey-extension.c,v 1.7 2006/01/22 13:43:20 crispin Exp $
+ *  $Id: ephy-greasemonkey-extension.c,v 1.8.2.1 2006/09/06 20:12:12 chpe Exp $
  */
 
 #include "config.h"
@@ -563,15 +563,6 @@ impl_attach_window (EphyExtension *ext,
 	gtk_ui_manager_add_ui (manager, ui_id, "/EphyLinkPopup",
 			       "GreasemonkeySep2", NULL,
 			       GTK_UI_MANAGER_SEPARATOR, TRUE);
-	gtk_ui_manager_add_ui (manager, ui_id, "/EphyImageLinkPopup",
-			       "GreasemonkeySep1", NULL,
-			       GTK_UI_MANAGER_SEPARATOR, TRUE);
-	gtk_ui_manager_add_ui (manager, ui_id, "/EphyImageLinkPopup",
-			       ACTION_NAME, ACTION_NAME,
-			       GTK_UI_MANAGER_MENUITEM, TRUE);
-	gtk_ui_manager_add_ui (manager, ui_id, "/EphyImageLinkPopup",
-			       "GreasemonkeySep2", NULL,
-			       GTK_UI_MANAGER_SEPARATOR, TRUE);
 }
 
 static void
@@ -665,7 +656,7 @@ ephy_greasemonkey_extension_get_type (void)
 GType
 ephy_greasemonkey_extension_register_type (GTypeModule *module)
 {
-	static const GTypeInfo our_info =
+	const GTypeInfo our_info =
 	{
 		sizeof (EphyGreasemonkeyExtensionClass),
 		NULL, /* base_init */
@@ -678,7 +669,7 @@ ephy_greasemonkey_extension_register_type (GTypeModule *module)
 		(GInstanceInitFunc) ephy_greasemonkey_extension_init
 	};
 
-	static const GInterfaceInfo extension_info =
+	const GInterfaceInfo extension_info =
 	{
 		(GInterfaceInitFunc) ephy_greasemonkey_extension_iface_init,
 		NULL,
