@@ -23,7 +23,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: page-info-dialog.c,v 1.51 2006/01/09 12:14:44 jframeau Exp $
+ *  $Id: page-info-dialog.c,v 1.51.4.1 2006/09/06 20:12:16 chpe Exp $
  */
 
 #include "config.h"
@@ -234,7 +234,7 @@ page_info_dialog_get_type (void)
 GType 
 page_info_dialog_register_type (GTypeModule *module)
 {
-	static const GTypeInfo our_info =
+	const GTypeInfo our_info =
 	{
 		sizeof (PageInfoDialogClass),
 		NULL, /* base_init */
