@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-permissions-dialog.c,v 1.4 2006/01/22 13:51:18 crispin Exp $
+ *  $Id: ephy-permissions-dialog.c,v 1.4.4.1 2006/09/06 20:12:16 chpe Exp $
  */
 
 #include "config.h"
@@ -724,7 +724,7 @@ ephy_permissions_dialog_get_type (void)
 
 	if (G_UNLIKELY (type == 0))
 	{
-		static const GTypeInfo our_info =
+		const GTypeInfo our_info =
 		{
 			sizeof (EphyPermissionsDialogClass),
 			NULL, /* base_init */
@@ -757,7 +757,7 @@ ephy_permissions_dialog_get_type (void)
 GType
 ephy_permissions_dialog_register_type (GTypeModule *module)
 {
-	static const GTypeInfo our_info =
+	const GTypeInfo our_info =
 	{
 		sizeof (EphyPermissionsDialogClass),
 		NULL, /* base_init */
