@@ -15,14 +15,13 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-rss-extension.c,v 1.7 2005/09/19 14:05:46 chpe Exp $
+ *  $Id: ephy-rss-extension.c,v 1.13.2.1 2006/09/06 20:12:22 chpe Exp $
  */
 
 #include "config.h"
 
 #include "ephy-rss-extension.h"
 #include "rss-ui.h"
-#include "rss-dbus.h"
 #include "rss-feedlist.h"
 
 #include "ephy-debug.h"
@@ -45,11 +44,15 @@
 
 #include <glib/gi18n-lib.h>
 
+#include <dbus/dbus-glib.h>
+
 #define EPHY_RSS_EXTENSION_GET_PRIVATE(object)	(G_TYPE_INSTANCE_GET_PRIVATE((object), EPHY_TYPE_RSS_EXTENSION, EphyRssExtensionPrivate))
 
 struct _EphyRssExtensionPrivate
 {
 	RssUI *dialog;
+	/* The proxy to the rss reader */
+	DBusGProxy *proxy;
 };
 
 static GObjectClass *parent_class = NULL;
@@ -57,6 +60,7 @@ static GType type = 0;
 
 /* Menu item stuff */
 #define WINDOW_DATA_KEY	"EphyRssExtensionWindowData"
+#define EPHY_RSS_EXTENSION_DATA_KEY "EphyRssExtension"
 #define MENU_PATH	"/menubar/ToolsMenu"
 
 /* Status Bar stuff */
@@ -130,16 +134,31 @@ ephy_rss_feed_subscribe_cb (GtkAction *action,
 			    EphyWindow *window)
 {
 	const GValue *value;
+	GError *error = NULL;
 	EphyEmbedEvent *event;
-
+	gboolean success;
+	EphyRssExtension *extension = EPHY_RSS_EXTENSION (g_object_get_data (
+												G_OBJECT (window),
+												EPHY_RSS_EXTENSION_DATA_KEY));
+	
 	LOG ("Subscribing to the feed");
 
 	event = ephy_window_get_context_event (window);
 	if (event == NULL) return;
 	
-	ephy_embed_event_get_property (event, "link", &value);
+	value = ephy_embed_event_get_property (event, "link");
 
-	rss_dbus_subscribe_feed (g_value_get_string (value));
+	
+
+	if (!dbus_g_proxy_call (extension->priv->proxy, RSS_DBUS_SUBSCRIBE, &error,
+		G_TYPE_STRING, g_value_get_string (value),
+		G_TYPE_INVALID,
+		G_TYPE_BOOLEAN, &success,
+		G_TYPE_INVALID))
+	{
+		LOG ("Error while retreiving method answer: %s", error->message);
+		g_error_free (error);
+	}
 	
 	g_object_set(action, "sensitive", FALSE, "visible", FALSE, NULL);	
 }
@@ -162,7 +181,7 @@ ephy_rss_ge_context_cb	(EphyEmbed *embed,
 		data = (WindowData *) g_object_get_data (G_OBJECT (window), WINDOW_DATA_KEY);
 		g_return_val_if_fail (data != NULL, FALSE);
 		
-		ephy_embed_event_get_property (event, "link", &value);
+		value = ephy_embed_event_get_property (event, "link");
 		address = g_value_get_string (value);
 		
 		active = rss_feedlist_contains (list, address);
@@ -196,12 +215,16 @@ ephy_rss_dialog_display (EphyWindow *window)
 	
 	if (priv->dialog == NULL)
 	{
+		RssUI **dialog;
+
 		LOG ("Trying to build dialog");
 		
 		priv->dialog = rss_ui_new (list, embed);
+
+		dialog = &priv->dialog;
 		
 		g_object_add_weak_pointer (G_OBJECT (priv->dialog),
-					   (gpointer *) &priv->dialog);
+					   (gpointer *) dialog);
 	}
 
 	ephy_dialog_set_parent (EPHY_DIALOG (priv->dialog),
@@ -437,13 +460,6 @@ impl_attach_window (EphyExtension *ext,
 			       "RssSubscribe", "RssSubscribe",
 			       GTK_UI_MANAGER_MENUITEM, FALSE);
 			       
-	gtk_ui_manager_add_ui (manager, ui_id, "/EphyImageLinkPopup",
-			       "RssInfoSep", NULL,
-			       GTK_UI_MANAGER_SEPARATOR, FALSE);
-	gtk_ui_manager_add_ui (manager, ui_id, "/EphyImageLinkPopup",
-			       "RssSubscribe", "RssSubscribe",
-			       GTK_UI_MANAGER_MENUITEM, FALSE);
-			       				
 	/* store data */
 	data = g_new (WindowData, 1);
 
@@ -456,6 +472,8 @@ impl_attach_window (EphyExtension *ext,
 	g_object_set_data_full (G_OBJECT (window), WINDOW_DATA_KEY, data,
 				(GDestroyNotify) g_free);
 
+	g_object_set_data (G_OBJECT (window), EPHY_RSS_EXTENSION_DATA_KEY, extension);
+	
 	/* Create the status bar icon */
 	ephy_rss_create_statusbar_icon (window, data);
 
@@ -491,13 +509,29 @@ impl_detach_window (EphyExtension *ext,
 
 	/* Destroy data */
 	g_object_set_data (G_OBJECT (window), WINDOW_DATA_KEY, NULL);
+	g_object_set_data (G_OBJECT (window), EPHY_RSS_EXTENSION_DATA_KEY, NULL);
 }
 
 /* Epiphany init/dispose stuff ------------------------- */
 static void
 ephy_rss_extension_init (EphyRssExtension *extension)
 {
+	DBusGConnection *connection;
+	GError *error = NULL;
 	extension->priv = EPHY_RSS_EXTENSION_GET_PRIVATE (extension);
+		
+	connection = dbus_g_bus_get (DBUS_BUS_SESSION, &error);
+	if (connection == NULL)
+	{
+		LOG ("No connection to dbus:%s", error->message);
+		g_error_free (error);
+		return;
+    }
+    	
+	extension->priv->proxy = dbus_g_proxy_new_for_name (connection,
+                                     RSS_DBUS_SERVICE,
+                                     RSS_DBUS_OBJECT_PATH,
+                                     RSS_DBUS_INTERFACE);
 }
 
 static void
@@ -505,12 +539,16 @@ ephy_rss_extension_finalize (GObject *object)
 {
 	EphyRssExtension *extension = EPHY_RSS_EXTENSION (object);
 
+	g_object_unref (extension->priv->proxy);
+	
 	/* Dispose the dialog */
 	if (extension->priv->dialog != NULL)
 	{
-		g_object_unref (extension->priv->dialog);
-		g_object_remove_weak_pointer (G_OBJECT (extension->priv->dialog),
-					      (gpointer *) &extension->priv->dialog);
+		RssUI **dialog = &extension->priv->dialog;
+
+		g_object_unref (*dialog);
+		g_object_remove_weak_pointer (G_OBJECT (*dialog),
+					      (gpointer *) dialog);
 	}
 
 	parent_class->finalize (object);
@@ -546,7 +584,7 @@ ephy_rss_extension_get_type (void)
 GType
 ephy_rss_extension_register_type (GTypeModule *module)
 {
-	static const GTypeInfo our_info =
+	const GTypeInfo our_info =
 	{
 		sizeof (EphyRssExtensionClass),
 		NULL, /* base_init */
@@ -559,7 +597,7 @@ ephy_rss_extension_register_type (GTypeModule *module)
 		(GInstanceInitFunc) ephy_rss_extension_init
 	};
 
-	static const GInterfaceInfo extension_info =
+	const GInterfaceInfo extension_info =
 	{
 		(GInterfaceInitFunc) ephy_rss_extension_iface_init,
 		NULL,
