@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-sample2-extension.c,v 1.8 2005/08/27 09:43:04 crispin Exp $
+ *  $Id: ephy-sample2-extension.c,v 1.8.6.1 2006/09/06 20:12:26 chpe Exp $
  */
 
 #include "config.h"
@@ -165,7 +165,7 @@ ephy_sample2_extension_get_type (void)
 GType
 ephy_sample2_extension_register_type (GTypeModule *module)
 {
-	static const GTypeInfo our_info =
+	const GTypeInfo our_info =
 	{
 		sizeof (EphySample2ExtensionClass),
 		NULL, /* base_init */
@@ -178,7 +178,7 @@ ephy_sample2_extension_register_type (GTypeModule *module)
 		(GInstanceInitFunc) ephy_sample2_extension_init
 	};
 
-	static const GInterfaceInfo extension_info =
+	const GInterfaceInfo extension_info =
 	{
 		(GInterfaceInitFunc) ephy_sample2_extension_iface_init,
 		NULL,
