@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-sample-extension.c,v 1.5 2005/01/28 22:30:17 chpe Exp $
+ *  $Id: ephy-sample-extension.c,v 1.5.10.1 2006/09/06 20:12:22 chpe Exp $
  */
 
 #include "config.h"
@@ -157,7 +157,7 @@ ephy_sample_extension_get_type (void)
 GType
 ephy_sample_extension_register_type (GTypeModule *module)
 {
-	static const GTypeInfo our_info =
+	const GTypeInfo our_info =
 	{
 		sizeof (EphySampleExtensionClass),
 		NULL, /* base_init */
@@ -170,7 +170,7 @@ ephy_sample_extension_register_type (GTypeModule *module)
 		(GInstanceInitFunc) ephy_sample_extension_init
 	};
 
-	static const GInterfaceInfo extension_info =
+	const GInterfaceInfo extension_info =
 	{
 		(GInterfaceInitFunc) ephy_sample_extension_iface_init,
 		NULL,
