@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id$
+ *  $Id: ephy-sidebar-extension.c,v 1.15.2.1 2006/09/06 20:12:27 chpe Exp $
  */
 
 #include "config.h"
@@ -36,6 +36,7 @@
 #include <epiphany/ephy-state.h>
 
 #include "ephy-file-helpers.h"
+#include "ephy-gui.h"
 #include "ephy-debug.h"
 
 #include <gtk/gtkactiongroup.h>
@@ -99,10 +100,10 @@ typedef struct
 static void cmd_view_sidebar	(GtkAction *action,
 				 EphyWindow *window);
 
-static GtkToggleActionEntry toggle_action_entries [] =
+static const GtkToggleActionEntry toggle_action_entries [] =
 {
 	{ "ViewSidebar", NULL, N_("_Sidebar"), "F9", 
-	  N_("Show or hide the sidebar"), G_CALLBACK(cmd_view_sidebar), FALSE }
+	  N_("Show or hide the sidebar"), G_CALLBACK (cmd_view_sidebar), FALSE }
 };
 
 static void ephy_sidebar_extension_class_init	(EphySidebarExtensionClass *klass);
@@ -126,7 +127,7 @@ ephy_sidebar_extension_get_type (void)
 GType
 ephy_sidebar_extension_register_type (GTypeModule *module)
 {
-	static const GTypeInfo our_info =
+	const GTypeInfo our_info =
 	{
 		sizeof (EphySidebarExtensionClass),
 		NULL, /* base_init */
@@ -139,7 +140,7 @@ ephy_sidebar_extension_register_type (GTypeModule *module)
 		(GInstanceInitFunc) ephy_sidebar_extension_init
 	};
 
-	static const GInterfaceInfo extension_info =
+	const GInterfaceInfo extension_info =
 	{
 		(GInterfaceInitFunc) ephy_sidebar_extension_iface_init,
 		NULL,
@@ -386,7 +387,10 @@ ephy_sidebar_extension_add_sidebar_cb (EphyEmbedSingle *single,
 	GtkWidget *dialog;
 	struct ResponseCallbackData *cb_data;
 	int i;
-	
+
+	session = EPHY_SESSION (ephy_shell_get_session (ephy_shell));
+	window = ephy_session_get_active_window (session);
+
 	/* See if the Sidebar is already added */
 	for (i = 0 ; i < ephy_node_get_n_children (extension->priv->sidebars); i++)
 	{
@@ -395,24 +399,44 @@ ephy_sidebar_extension_add_sidebar_cb (EphyEmbedSingle *single,
 		
 		if (strcmp (node_url, url) == 0)
 		{
-			/* TODO Should we raise a dialog or perform an action here */
+			dialog = gtk_message_dialog_new
+				(GTK_WINDOW (window),
+				 GTK_DIALOG_DESTROY_WITH_PARENT,
+				 GTK_MESSAGE_INFO,
+				 GTK_BUTTONS_OK,
+				 /* Translators: %s is the sidebar title */
+				 _("The sidebar already contains “%s”"), title);
+
+			gtk_message_dialog_format_secondary_text
+				(GTK_MESSAGE_DIALOG (dialog),
+				 _("To use this sidebar, select it from the list of available "
+					 "sidebar pages."));
+
+			gtk_window_set_title (GTK_WINDOW (dialog), _("Add Sidebar"));
+			gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
+
+			gtk_window_group_add_window (ephy_gui_ensure_window_group
+					(GTK_WINDOW (window)), GTK_WINDOW (dialog));
+
+			g_signal_connect (dialog, "response", G_CALLBACK
+					(gtk_widget_destroy), NULL);
+
+			gtk_widget_show (GTK_WIDGET (dialog));
+
 			return TRUE;
 		}
 	}
 
-	session = EPHY_SESSION (ephy_shell_get_session (ephy_shell));
-	window = ephy_session_get_active_window (session);
-
 	dialog = gtk_message_dialog_new
 		(GTK_WINDOW (window),
 		 GTK_DIALOG_DESTROY_WITH_PARENT,
 		 GTK_MESSAGE_QUESTION,
 		 GTK_BUTTONS_CANCEL,
-		 _("Add \"%s\" to the Sidebar?"), title);
+		 _("Add “%s” to the Sidebar?"), title);
 
 	gtk_message_dialog_format_secondary_text
 		(GTK_MESSAGE_DIALOG (dialog),
-		 _("The source to the new sidebar page is %s."), url);
+		 _("The source to the new sidebar page is “%s”."), url);
 
 	gtk_window_set_title (GTK_WINDOW (dialog), _("Add Sidebar"));
 	gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
@@ -526,8 +550,7 @@ impl_attach_window (EphyExtension *ext,
 	ephy_state_add_paned (hpaned, "EphySidebarExtension::HPaned", 220);
 
 	data->embed = ephy_sidebar_embed_new (window);
-	g_object_ref (data->embed);
-	gtk_object_sink (GTK_OBJECT (data->embed));
+	g_object_ref_sink (data->embed);
 
 	g_signal_connect (sidebar, "page_changed", 
 			  G_CALLBACK(sidebar_page_changed_cb), data);
@@ -689,8 +712,8 @@ ephy_sidebar_extension_finalize (GObject *object)
 		 (const xmlChar*) EPHY_SIDEBARS_XML_ROOT,
 		 (const xmlChar*) EPHY_SIDEBARS_XML_VERSION,
 		 NULL,
-		 extension->priv->sidebars, 0, 
-		 extension->priv->state_parent, 0, 
+		 extension->priv->sidebars, NULL, NULL, 
+		 extension->priv->state_parent, NULL, NULL, 
 		 NULL);
 
 	g_free (extension->priv->xml_file);
