@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: smart-bookmarks-extension.c,v 1.18 2006/03/23 23:15:47 jframeau Exp $
+ *  $Id: smart-bookmarks-extension.c,v 1.19.2.1 2006/09/06 20:12:30 chpe Exp $
  */
 
 #include "config.h"
@@ -88,7 +88,7 @@ smart_bookmarks_extension_get_type (void)
 GType
 smart_bookmarks_extension_register_type (GTypeModule *module)
 {
-	static const GTypeInfo our_info =
+	const GTypeInfo our_info =
 	{
 		sizeof (SmartBookmarksExtensionClass),
 		NULL, /* base_init */
@@ -101,7 +101,7 @@ smart_bookmarks_extension_register_type (GTypeModule *module)
 		(GInstanceInitFunc) smart_bookmarks_extension_init
 	};
 
-	static const GInterfaceInfo extension_info =
+	const GInterfaceInfo extension_info =
 	{
 		(GInterfaceInitFunc) smart_bookmarks_extension_iface_init,
 		NULL,
@@ -304,12 +304,6 @@ rebuild_ui (WindowData *data)
 	gtk_ui_manager_add_ui (manager, ui_id, "/EphyDocumentPopup",
 			       LOOKUP_ACTION "Menu", LOOKUP_ACTION,
 			       GTK_UI_MANAGER_MENU, FALSE);
-	gtk_ui_manager_add_ui (manager, ui_id, "/EphyFullscreenDocumentPopup",
-			       "SmbExtSep0", NULL,
-			       GTK_UI_MANAGER_SEPARATOR, FALSE);
-	gtk_ui_manager_add_ui (manager, ui_id, "/EphyFullscreenDocumentPopup",
-			       LOOKUP_ACTION "Menu", LOOKUP_ACTION,
-			       GTK_UI_MANAGER_MENU, FALSE);
 
 	/* Add bookmarks to input popup context */
 	gtk_ui_manager_add_ui (manager, ui_id, "/EphyInputPopup",
@@ -341,10 +335,6 @@ rebuild_ui (WindowData *data)
 				       "/EphyDocumentPopup/" LOOKUP_ACTION "Menu",
 				       verb, verb,
 				       GTK_UI_MANAGER_MENUITEM, FALSE);
-		gtk_ui_manager_add_ui (manager, ui_id,
-				       "/EphyFullscreenDocumentPopup/" LOOKUP_ACTION "Menu",
-				       verb, verb,
-				       GTK_UI_MANAGER_MENUITEM, FALSE);
 		gtk_ui_manager_add_ui (manager, ui_id,
 				       "/EphyInputPopup/" LOOKUP_ACTION "Menu",
 				       verb, verb,
@@ -358,10 +348,6 @@ rebuild_ui (WindowData *data)
 			       "/EphyDocumentPopup/" LOOKUP_ACTION "Menu",
 			       GDICT_ACTION "IDP", GDICT_ACTION,
 			       GTK_UI_MANAGER_MENUITEM, FALSE);
-	gtk_ui_manager_add_ui (manager, ui_id,
-			       "/EphyFullscreenDocumentPopup/" LOOKUP_ACTION "Menu",
-			       GDICT_ACTION "FSIDP", GDICT_ACTION,
-			       GTK_UI_MANAGER_MENUITEM, FALSE);
 	gtk_ui_manager_add_ui (manager, ui_id,
 			       "/EphyInputPopup/" LOOKUP_ACTION "Menu",
 			       GDICT_ACTION "INPUTP", GDICT_ACTION,
