@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-tab-grouper.c,v 1.9 2006/03/25 20:53:34 jframeau Exp $
+ *  $Id: ephy-tab-grouper.c,v 1.9.2.1 2006/09/06 20:12:30 chpe Exp $
  */
 
 #include "config.h"
@@ -59,7 +59,7 @@ ephy_tab_grouper_get_type (void)
 GType
 ephy_tab_grouper_register_type (GTypeModule *module)
 {
-	static const GTypeInfo our_info =
+	const GTypeInfo our_info =
 	{
 		sizeof (EphyTabGrouperClass),
 		NULL, /* base_init */
